function [valid,Bmin,Bvermin,LXsol,zcap,D1,Z1,Y,X0,V,XV] = vertex(B,XB,N,ex1,zcap,LXsol,D1,Z1,Y)
// Vertex Property applied on given polynomial function. 
//
// Calling Sequence
//   [valid,Bmin,Bvermin,zcap] = vertex(B,XB,N,ex1,zcap,LXsol,D1,Z1,Y) 
//
// Parameters
// B : Original Berstein Coefficient 
// XB: Original Box(es)
// N : Dimensional (Row) Matrix for all Variables in the Polynomial
//ex1: Tolerence on the Bounds
//zcap: Global Minimum Estimate
//LXsol: Temporary List for all minimzers at which Global minimum may lie
//D1: Total Number of Bernstein coefficients at vertices (Bvermin)
//Z1: Total Number of Global Minimum Estimate (zcap)
//Y : New Bounds Calculated from Vertex Property
//valid : Indicates boxes feasible (valid=1) or boxes infeasible (valid=0)
//Bmin : Minimum Bernstein Coefficient Value
//
// Description
// Vertex property plays vital role for finding out the global minimum.  
//
//Examples
// // Vertex Property applied on given polynomial function
// [valid,Bmin,Bvermin,zcap] = vertex(B,XB,N,ex1,zcap,LXsol,D1,Z1,Y)
// // Function calculates estimate minimum position and compares with vertices value.
//
// See also
//  store
//  getverind
//  sun2lin
//  ind2x
//  lin2sub
//
// Authors
//  Mr. Dhiraj B. Magare
//  IDP in Systems and Control Engineering
//  Indian Institute of Technology Bombay;
//
//  Mr. Bhagyesh V. Patil
//  IDP in Systems and Control Engineering
//  Indian Institute of Technology Bombay;
//
//  Prof. P.S.V. Nataraj
//  IDP in Systems and Control Engineering
//  Indian Institute of Technology Bombay
// 
// Bibliography
//1. Shashwati Ray, P.S.V. Nataraj. An efficient algorithm for range computation of polynomials using the Bernstein form. Journal of Global Optimization, 45: 403-426,2009;
//2.	G. T. Cargo and O. Shisha. The Bernstein form of a polynomial. Jl. of research of NBS,70B:79-81,1966.
//3. S. Ray, A new approach to range computation of polynomial problems using the Bernstein form. PhD thesis, Systems and Control Engineering, IIT Bombay, India, 2007.
//

    valid=0;
    B1=matrix(B,1,-1);
    Bmin=min(B1);
    verind=getverind(N);
    Bvermin=min(B1(verind));
    if (Bmin==Bvermin)  then,  
      valid=0;
      zcap=min(zcap,Bvermin);
      for i=1:size(verind,'c'),  
         if Bmin==B1(verind(i)) then, 
            X0=ind2x(verind(i),XB,N+1)
            V=verind(i);
            XV=XB;
            Y=0;
            Y=[X0 X0];
            [LXsol,Bvermin,zcap,D1,Z1,Y]=store(Y,Bvermin,zcap,LXsol,D1,Z1)
         end,        
      end,
    elseif ((Bmin+ex1)<Bvermin)|(mtlb_any((XB(:,2)-XB(:,1))>ex1)) then,
       valid=1; 
 
    else
      valid=0;
      [LXsol,Bvermin,zcap,D1,Z1,Y]=store(Y,Bvermin,zcap,LXsol,D1,Z1);
      zcap=min(zcap,Bvermin);
    end,
endfunction;
  
